<?php

// require_once 'Symfony/Component/Security/Core/autoload.php'; (already required by Guard)
require_once 'Symfony/Component/Security/Csrf/autoload.php';
require_once 'Symfony/Component/Security/Guard/autoload.php';
// require_once 'Symfony/Component/Security/Http/autoload.php'; (already required by Guard)
