<?php
// suggest:
if (stream_resolve_include_path('Symfony/Component/HttpFoundation/autoload.php')){
    include_once 'Symfony/Component/HttpFoundation/autoload.php';
}
if (stream_resolve_include_path('Symfony/Component/Config/autoload.php')){
    include_once 'Symfony/Component/Config/autoload.php';
}
if (stream_resolve_include_path('Symfony/Component/Yaml/autoload.php')){
    include_once 'Symfony/Component/Yaml/autoload.php';
}
if (stream_resolve_include_path('Symfony/Component/ExpressionLanguage/autoload.php')){
    include_once 'Symfony/Component/ExpressionLanguage/autoload.php';
}
if (stream_resolve_include_path('Doctrine/Common/Annotations/autoload.php')){
    include_once 'Doctrine/Common/Annotations/autoload.php';
}

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn]) and file_exists(___BASEDIR___$classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    },
    true,
    false
);
// @codeCoverageIgnoreEnd
