<?php

require_once 'Symfony/autoload.php';
require_once 'Symfony/Bridge/PhpUnit/autoload.php';

require_once 'Composer/autoload.php';
require_once 'Cache/IntegrationTests/autoload.php';
require_once 'Doctrine/Bundle/DoctrineBundle/autoload.php';
require_once 'GuzzleHttp/Promise/autoload.php';
require_once 'Http/Client/autoload.php';
require_once 'Masterminds/HTML5/autoload.php';
require_once 'Nyholm/Psr7/autoload.php';
// Predis is installed in a pretty weird path, see #779418
require_once 'php-nrk-predis/Autoloader.php';
Predis\Autoloader::register();
require_once 'Psr/Http/Client/autoload.php';
require_once 'Psr/SimpleCache/autoload.php';
require_once 'Twig/Extra/CssInliner/autoload.php';
require_once 'Twig/Extra/Inky/autoload.php';
require_once 'Twig/Extra/Markdown/autoload.php';

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn]) and file_exists(___BASEDIR___$classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    },
    true,
    false
);
// @codeCoverageIgnoreEnd
